# Contributor covenant code of conduct

## Our pledge

In the interest of fostering an open and welcoming environment, we as contributors and maintainers pledge to making
participation in our project and our community a harassment-free experience for everyone, regardless of age, body size,
disability. Please read the [latest full version here](https://www.contributor-covenant.org/).